# GRID

## Github page

https://poissonfish.github.io/GRID/

## Update Log

### Oct 29, 2019 (0.2.0)
    * Add progress bars
    * Enhance the support for low resolution monitors
    * Improve UI
  
### Oct 22, 2019 (0.1.3)
    * Optimize default setting of refining parameters
    * Fix wrong angle detection
    * Minor bug fixes

### Oct 19, 2019 (0.1.2)
    * Support rhombus field layout
    * Bug fixes

### Sep 17, 2019 (0.0.16)
    * Improve memory efficiency on Windows OS

### Sep 12, 2019 (0.0.15)
    * Fix problems wiht fixed segmentation
    * Organize file structure
    * Add dark mode
